@@ -3,15 +3,16 @@ Main interface for kms service.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.kms import (
+    from mypy_boto3_kms import (
         Client,
         KMSClient,
         ListAliasesPaginator,
         ListGrantsPaginator,
         ListKeyPoliciesPaginator,
         ListKeysPaginator,
-        )
+    )
 
     session = boto3.Session()
 
@@ -22,8 +23,9 @@ Usage::
     list_grants_paginator: ListGrantsPaginator = client.get_paginator("list_grants")
     list_key_policies_paginator: ListKeyPoliciesPaginator = client.get_paginator("list_key_policies")
     list_keys_paginator: ListKeysPaginator = client.get_paginator("list_keys")
+    ```
 """
-from mypy_boto3_kms.client import KMSClient, KMSClient as Client
+from mypy_boto3_kms.client import KMSClient as Client, KMSClient
 from mypy_boto3_kms.paginator import (
     ListAliasesPaginator,
     ListGrantsPaginator,
