@@ -3,8 +3,11 @@ Main interface for kms service client paginators.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.kms import (
+
+    from mypy_boto3_kms import KMSClient
+    from mypy_boto3_kms import (
         ListAliasesPaginator,
         ListGrantsPaginator,
         ListKeyPoliciesPaginator,
@@ -17,6 +20,7 @@ Usage::
     list_grants_paginator: ListGrantsPaginator = client.get_paginator("list_grants")
     list_key_policies_paginator: ListKeyPoliciesPaginator = client.get_paginator("list_key_policies")
     list_keys_paginator: ListKeysPaginator = client.get_paginator("list_keys")
+    ```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 from typing import Iterator, TYPE_CHECKING
@@ -40,51 +44,51 @@ __all__ = (
 
 class ListAliasesPaginator(Boto3Paginator):
     """
-    [Paginator.ListAliases documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/kms.html#KMS.Paginator.ListAliases)
+    [Paginator.ListAliases documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/kms.html#KMS.Paginator.ListAliases)
     """
 
     def paginate(
         self, KeyId: str = None, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListAliasesResponseTypeDef]:
         """
-        [ListAliases.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/kms.html#KMS.Paginator.ListAliases.paginate)
+        [ListAliases.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/kms.html#KMS.Paginator.ListAliases.paginate)
         """
 
 
 class ListGrantsPaginator(Boto3Paginator):
     """
-    [Paginator.ListGrants documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/kms.html#KMS.Paginator.ListGrants)
+    [Paginator.ListGrants documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/kms.html#KMS.Paginator.ListGrants)
     """
 
     def paginate(
         self, KeyId: str, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListGrantsResponseTypeDef]:
         """
-        [ListGrants.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/kms.html#KMS.Paginator.ListGrants.paginate)
+        [ListGrants.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/kms.html#KMS.Paginator.ListGrants.paginate)
         """
 
 
 class ListKeyPoliciesPaginator(Boto3Paginator):
     """
-    [Paginator.ListKeyPolicies documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/kms.html#KMS.Paginator.ListKeyPolicies)
+    [Paginator.ListKeyPolicies documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/kms.html#KMS.Paginator.ListKeyPolicies)
     """
 
     def paginate(
         self, KeyId: str, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListKeyPoliciesResponseTypeDef]:
         """
-        [ListKeyPolicies.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/kms.html#KMS.Paginator.ListKeyPolicies.paginate)
+        [ListKeyPolicies.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/kms.html#KMS.Paginator.ListKeyPolicies.paginate)
         """
 
 
 class ListKeysPaginator(Boto3Paginator):
     """
-    [Paginator.ListKeys documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/kms.html#KMS.Paginator.ListKeys)
+    [Paginator.ListKeys documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/kms.html#KMS.Paginator.ListKeys)
     """
 
     def paginate(
         self, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListKeysResponseTypeDef]:
         """
-        [ListKeys.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/kms.html#KMS.Paginator.ListKeys.paginate)
+        [ListKeys.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/kms.html#KMS.Paginator.ListKeys.paginate)
         """
